{% extends "base.html" %}
{% block title %}{{ page.title }}{% endblock %}
{% block content %}        
<section id="content" class="body">    
    <h2>{{ page.title }}</h2>
    {{ page.content }}
</section>
{% endblock %}
